'use strict';
/*
 * Copyright 2018 Amazon.com, Inc. and its affiliates. All Rights Reserved.
 * Licensed under the Amazon Software License (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * http://aws.amazon.com/asl/
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */


/**
 * Questions library
 * 
 * Use this file to create your own set of questions.
 * 
 * Object properties:
 *      index:          The index of the question in this list
 *      question:       The question you want Alexa to ask
 *      answers:        The list of available answers
 *      correct_answer: The correct answer to the question
 * 
 * When adding or updating questions and answers, you must take the list of all values 
 * in each of the 'answers' arrays for all questions and add them to a custom slot 
 * in your skill called 'answers'.
 * 
 * The 'answers' custom slot is be mapped to a couple of intents in the interaction model.
 * One intent, named 'AnswerOnlyIntent', contains only the slot, by itself, in order 
 * to maximize the accuracy of the model.
 * 
 * For example: 
 *      AnswerOnlyIntent {answers}
 * 
 * The other intent, 'AnswerQuestionIntent', provides more complex speech patterns
 * to match other utternaces users may include with their answers.
 * 
 * For example:
 *      AnswerQuestionIntent is it {answers}
 *      AnswerQuestionIntent it is {answers}
 *      AnswerQuestionIntent the answer is {answers}
 *      AnswerQuestionIntent I think the answer is {answers}
 * 
 * See model file at models/en-US.json for a complete example.
 */
module.exports = Object.freeze({ 
    "questions": {
      "en": {
        "us": [
            {
                "index": 1,
                "question": "One-odio bluetooth bass headphones. It has professional quality sound, detachable extended mic, 30 hours playback time after two hours charging, and weighs 7.58 pounds.",
                "answers": ["17", "27", "37", "67"],
                "correct_answer": "37"
            },
            {
                "index": 2,
                "question": "Anki vector, home robot who helps you out. Powered by AI and advanced robotics, he's alive with personality and engaged by sight, sound, and touch. Curious and attentive, he's voice-activated and will answer questions, take photos for you, time dinner, show you the weather, and more. Vector can independently navigate and self-charge. He recognizes people and avoids obstacles.",
                "answers": ["250", "500", "750", "1000"],
                "correct_answer": "250"
            },
            {
                "index": 3,
                "question": "I LIFE robot vacuum cleaner. Automatically starts on its scheduling program and returns to charging station to recharge when battery runs low. Multiple smart sensors avoid bumping around or falling off stairs. It even cleans under beds, along the walls and around the clutter. Dirt can not hide. Superior battery-group brings up to 140mins cleaning time and prolongs life time. Cleaning system with a strong suction provides thorough and concentrated cleaning.",
                "answers": ["125", "250", "375", "500"],
                "correct_answer": "250"
            },
            {
                "index": 4,
                "question": "Bosch compact tough drill kit with 2 lithium ion batteries and 18V charger. At only 3 lbs, it provides 350 pounds of optimized torque for powerful fastening and 1300 RPM for fast, efficient power drilling. Two speed transmission, one for heavy duty projects and one for speed, provides both optimized torque and efficiency for powerful screw driving and precise drilling.",
                "answers": ["300", "450", "700", "1000"],
                "correct_answer": "450"
            },
            {
                "index": 5,
                "question": "Mr. coffee cafe barista espresso and cappuccino maker. Semi-automatic 3-in-1 espresso maker, cappuccino maker, and latte maker. 15-bar pump system brews rich-tasting espresso coffee. Trouble-free automatic milk frother removes the guesswork. One-touch control panel for drink selections. Easy-fill, removable water and milk reservoirs.",
                "answers": ["50", "75", "100", "200"],
                "correct_answer": "100"
            },
            {
                "index": 6,
                "question": "Portable air pump with pressure gauge battery for cars, motorbike, basketball. Built-in large rechargeable 2000 mAh Li-on battery, only takes 3-6 minutes to inflate a tire. 12V Tire inflator with LCD display can simply preset the desired pressure. Electric air pump will automatically shut off when reaching the proper inflation value.",
                "answers": ["30", "65", "105", "325"],
                "correct_answer": "65"
            },
            {
                "index": 7,
                "question": "Plug-in carbon monoxide detector. Features an advanced electrochemical carbon monoxide sensor, that accurately detects carbon monoxide levels, no matter where the detector is placed in the room. A loud 85-decibel alarm sounds when carbon monoxide levels reach dangerous levels. 7-year limited warranty. ",
                "answers": ["20", "35", "65", "85"],
                "correct_answer": "65"
            },
            {
                "index": 8,
                "question": "Bear archery beginner bow set. Comes ready to shoot with two arrows and target. Also includes finger rollers, armguard, and arrow quiver. Features 8-12 pound draw-weight and 14 to 16 inch draw length range. Recommended age range for children is 4 to 7 years old.",
                "answers": ["15", "25", "45", "65"],
                "correct_answer": "25"
            },
            {
                "index": 9,
                "question": "Coleman Sundome 4-person tent. Dome shaped tent with spacious interior allows you to move comfortably. Easy setup in only 10 minutes. WeatherTec system with patented welded floors and inverted seams, to keep you dry. Large windows and a ground vent for superior ventilation. Measures 9 x 7 feet with 4-foot 11-inch center height.",
                "answers": ["85", "145", "225", "360"],
                "correct_answer": "85"
            },
            {
                "index": 10,
                "question": "Black Diamond momentum harness for mountain climbing. Medium size. Bullhorn-shaped waist belt uses dual core construction for comfort. trakFIT leg loop adjustment. Adjustable elastic riser straps.",
                "answers": ["15", "35", "55", "75"],
                "correct_answer": "55"
            },
            {
                "index": 11,
                "question": "Hot Wheels basic car 50-pack. The vehicles in the collection feature realistic details and authentic decos. Cars are individually packaged so they can be shared for any occasion or kept as one collection.",
                "answers": ["15", "25", "35", "55"],
                "correct_answer": "55"
            },
            ]
        }
    }
});
